package GT::Maildir::Lock;

use strict;
use warnings;

use Carp qw/croak confess/;

sub new {
    my $class = shift;
    croak "Unknown arguments to $class->new: ", join(", ", @_) if @_;
    return bless {}, $class;
}

sub ex_lock {
    my $self = shift;
    croak "No file specified to $self->ex_lock" unless @_;
    my $file = shift;
    croak "Invalid file passed to $self->ex_lock" unless length $file and defined $file;
    my $blocking_timeout = shift || 0;
    my $stale_lock_timeout = shift || 0;
    croak "Unknown arguments to $self->ex_lock: ", join(", ", @_) if @_;
    return $self->do_lock($file, "EX", $blocking_timeout, $stale_lock_timeout);
}

sub sh_lock {
    my $self = shift;
    croak "No file specified to $self->sh_lock" unless @_;
    my $file = shift;
    croak "Invalid file passed to $self->sh_lock" unless length $file and defined $file;
    my $blocking_timeout = shift || 0;
    my $stale_lock_timeout = shift || 0;
    croak "Unknown arguments to $self->sh_lock: ", join(", ", @_) if @_;
    return $self->do_lock($file, "SH", $blocking_timeout, $stale_lock_timeout);
}

sub unlock {
    my $self = shift;
    croak "No file specified to $self->unlock" unless @_;
    my $file = shift;
    croak "Invalid file specified to $self->unlock" unless length $file and defined $file;
    croak "Unknown arguments to $self->unlock: ", join(", ", @_) if @_;
    return $self->do_unlock($file);
}

sub set_errorstr {
    my $self = shift;
    $self->{errorstr} = join "", @_;
}

sub get_errorstr {
    my $self = shift;
    croak "Unknown arguments to $self->get_errorstr: ", join(", ", @_) if @_;
    return $self->{errorstr};
}

sub do_lock {
    confess "This virtual method must be implemented in a subclass";
}

sub do_unlock {
    confess "This virtual method must be implemented in a subclass";
}

sub DESTROY {
}

1;

