package GT::Maildir::Search::Query;

use strict;
use warnings;

use vars qw/@EXPORT/;
use Carp qw/croak/;
use Exporter();

*import = \&Exporter::import;

@EXPORT = qw(
    GQUERY_AND
    GQUERY_OR
);

sub GQUERY_AND () { 1 }
sub GQUERY_OR  () { 2 }

sub new {
    my $class = shift;

    croak "Invalid arguments to $class->new. Arguments must be key/value pairs" if @_ & 1;

    my %opts = @_;
    $opts{ lc $_ } = delete $opts{$_} for keys %opts;

    my $bool = delete $opts{bool};
    croak "No bool specified to $class->new" unless defined $bool;

    my $terms = delete $opts{terms};
    croak "No query specified to $class->new" unless defined $terms;

    croak "Unknown arguments to $class->new: ", join(", ", keys %opts) if keys %opts;

    return bless {
        bool => $bool,
        terms => $terms
    };
}

sub get_bool {
    my $self = shift;
    croak "Unknown arguments to $self->get_bool" if @_;
    return $self->{bool};
}

sub get_terms {
    my $self = shift;
    croak "Unknown arguments to $self->get_terms" if @_;
    return [ @{$self->{terms}} ];
}

sub as_string {
    my $self = shift;
    croak "Unknown arguments to $self->as_string" if @_;

    my $bool_string = $self->{bool} == GQUERY_AND ? " AND " : " OR ";
    return join($bool_string, map { '(' . $_->as_string . ')' } @{$self->{terms}});
}

1;

