package GT::Maildir::Search::Term;

use strict;
use warnings;

use Carp qw/croak/;

sub new {
	my $class = shift;

	croak "Invalid arguments to $class->new. Arguments must be key/value pairs" if @_ & 1;

	my %opts = @_;
	$opts{ lc $_ } = delete $opts{$_} for keys %opts;

	# Default field is used if this is not defined
	my $field = delete $opts{field};

	croak "No query specified to $class->new" unless exists $opts{query};
	my $query = delete $opts{query};

	croak "Unknown arguments to $class->new: ", join(", ", keys %opts) if keys %opts;

	return bless {
		field => ($field ? lc($field) : undef),
		query => $query
	}, $class;
}

sub get_field {
	my $self = shift;
	croak "Unknown arguments to $self->get_field" if @_;
	return $self->{field};
}

sub get_query {
	my $self = shift;
	croak "Unknown arguments to $self->get_query" if @_;
	return $self->{query};
}

sub as_string {
	my $self = shift;
	croak "Unknown arguments to $self->as_string" if @_;

	return $self->{field} ? "$self->{field}:($self->{query})" : "($self->{query})"
}

1;

